//***********************************************************************
// Name of Program : TEST1.C                                            //
//************************************************************************
// Purpose         : This program is created to apply and test the     //
//                 : "io.h" and "io.lib" for AIO adapters.                    //
//*************************************************************************

#include <dos.h>
#include <conio.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <ctype.h>
//***********************************************************************
// Name of Structure : ADDA_CONVTAB                                    //
//***********************************************************************
// Purpose           : This structure is used in all A/D-D/A adapters //
//                   : for data conversion from analog value to       //
//                   : digital value                                  //
//***********************************************************************
ADDA_CONVTAB
	//**************************************************************
	// Pocket 12 Conversion table
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0xfff, 10,00 = number of resolution to maximum digital value
	// 0V to 10 Volts at 12-bit
	//**************************************************************
	PAD12_tab = {
	      {{0,0.00},{0xfff,10.00} },  // 12-bit resolution, 10 Volts
	      { {0,0 } }   // don't care for Pocket
		    },

	//**************************************************************
	// Pocket 10 Conversion table
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0x3ff, 10,00 = number of resolution to maximum digital value
	// 0V to 10 Volts at 10-bit
	//**************************************************************
	PAD10_tab = {
	      {{0,0.00},{0x3ff,10.00} },  // 10-bit resolution, 10 volts
	      { {0,0 } }   // don't care for Pocket
		    },

	//**************************************************************
	// 12-Bit A/D-D/A Adapter
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0xfff, 9.00 = number of resolution to maximum digital value
	// 0.00, 9.00  = reprents the voltage range ( 0V to 9V)
	//**************************************************************
	ADDA12_tab = {
	      {{0,0.00}, {0xfff,9.00}},   // 12-bit resolution, 9V Unipolat A/D
	      { {0.00,9.00},{0.00,9.00}}  // Voltage range for 2 D/A
		     },

	//**************************************************************
	// 12-Bit SUPER A/D-D/A Adapter
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0xfff, 10.00 = number of resolution to maximum digital value
	// 0.00, 10.00  = reprents the voltage range ( 0V to 10V)
	//**************************************************************
	SADDA12_tab = {
	    { {0,0.00},{0xfff,10.00}   },  // 12-bit resolution, 10V Unipolar A/D
	    { {0.00,10.00},{0.00,10.00} }  // voltage range for 2 D/A
		    },

	//**************************************************************
	// 14-Bit A/D-D/A Adapter
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0x3fff, 10.00 = number of resolution to maximum digital value
	// 0.00, 10.00  = reprents the voltage range ( 0V to 10V)
	//**************************************************************
	SADDA14_tab = {
	    { {0,0.00},{0x3fff,10.00}   },   // 14-bit resolution, 10V unipolar A/D
	    { {0.00,10.00},{0.00,10.00} }    // voltage range for 2 D/A
		    },

	//**************************************************************
	// 12-Bit Advanvec A/D-D/A
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0xfff, 10.00 = number of resolution to maximum digital value
	// 0.00, 10.00  = reprents the voltage range ( 0V to 10V)
	//**************************************************************
	AADDA12_tab = {
	    { { 0,0.00}, {0xfff,10.00} },  // 12-bit resolution, 10V unipolar A/D
	    { {0.00,10.00}, {0.00,10.00} } // voltage range for 2 D/A
		    },

	//**************************************************************
	// 12-Bit High Performance A/D-D/A
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0xfff, 10.00 = number of resolution to maximum digital value
	// 0.00, 10.00  = reprents the voltage range ( 0V to 10V)
	//**************************************************************
	HIADDA12_tab = {
	    { {0,0.00}, {0xfff,10.00} },    // 12-bit resolution, 10V unipolar A/D
	    { {0.00,10.00}, {0.00, 10.00} } // voltage range for 2 D/A
		    },

	//**************************************************************
	// 14-Bit High Performance A/D-D/A
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0x3fff, 10.00 = number of resolution to maximum digital value
	// 0.00, 10.00  = reprents the voltage range ( 0V to 10V)
	//**************************************************************
	HIADDA14_tab = {
	    { {0,0.00}, {0x3fff,10.00} },   // 14-bit resolution, 10V unipolar A/D
	    { {0.00,10.00}, {0.00, 10.00} } // voltage range for 2 D/A
		    },

	//**************************************************************
	// 16-Bit High Performance A/D-D/A
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0xffff, 10.00 = number of resolution to maximum digital value
	// 0.00, 10.00  = reprents the voltage range ( 0V to 10V)
	//**************************************************************
	HIADDA16_tab = {
	    { {0,0.00}, {0xffff,10.00} },    // 160bit resolution, 10V unipolar A/D
	    { {0.00,10.00}, {0.00, 10.00} }  // voltage range for 2 D/A
		    },

	//**************************************************************
	// 8-Bit D/A 8-Channel
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0xff, 9.00 = number of resolution to maximum digital value
	// 0.00, 9.00  = reprents the voltage range ( 0V to 10V) at 8 channels
	//**************************************************************
	DA8_tab     = {
	    { {0,0.00}, {0xff,9.00} },  // 8-bit resolution, 9V unipolar
	    { {0.00,9.00}, {0.00, 9.00},{0.00,9.00}, {0.00, 9.00},  // voltage range for 8 D/A
	       {0.00,9.00}, {0.00, 9.00},{0.00,9.00}, {0.00, 9.00}}
		    },

	//**************************************************************
	// 12-Bit D/A 8-Channel
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0xfff, 9.00 = number of resolution to maximum digital value
	// 0.00, 9.00  = reprents the voltage range ( 0V to 10V) at 8 channels
	//**************************************************************
	DA12_tab     = {
	    { {0,0.00}, {0xfff,9.00} },  //8-bit resolution, 9V unipolar
	    { {0.00,9.00}, {0.00, 9.00},{0.00,9.00}, {0.00, 9.00}, // voltage range for 8 D/A
	       {0.00,9.00}, {0.00, 9.00},{0.00,9.00}, {0.00, 9.00}}
		    },

	//**************************************************************
	// 14-Bit D/A 8-Channel
	// 0, 0.00 = minimum digital value to minimum analog value
	// 0x3fff, 9.00 = number of resolution to maximum digital value
	// 0.00, 9.00  = reprents the voltage range ( 0V to 10V) at 8 channels
	//**************************************************************
	DA14_tab     = {
	    { {0,0.00}, {0x3fff,9.00} },   // 14-bit resolution, 9V unipolar
	    { {0.00,9.00}, {0.00, 9.00},{0.00,9.00}, {0.00, 9.00}, // voltage range for 8 D/A
	       {0.00,9.00}, {0.00, 9.00},{0.00,9.00}, {0.00, 9.00}}
		    };


int ioaddr;    // variable for getting the base address in hex
int mode;      // specifies the Single-Ended = 16 and Differential = 8
int chans;     // specifies the channels

//**********************************************************************
//Name of function :  void RunPocket12 (int anum)                     //
//--------------------------------------------------------------------//
//Purpose          : This is used to run pocket 12                    //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioget(anum,chans) = is used to read the digital value from input
//		       chans (channels) of the (Pocket 12 AD)
//**********************************************************************
void RunPocket12(int anum){
     clrscr();
     gotoxy(25,2);printf("12 Bit Pocket A/D Test");
     gotoxy(25,20); printf("PRESS P to Pause, PRESS Q to Quit");
     while(1){
	gotoxy(1,3);
	clreol();
	for (chans=0; chans<11; chans++)    // 10 channels
	printf("Received Value Channel  %2d   %4.2f  \n", chans, ioget(anum,chans));
	delay(500);
	if(bioskey(1))
	 switch( toupper(getch()) ){
		case 'Q':  return;    // quit test program
		case 'P':  getch();   // pause
		 }

      }
}


//**********************************************************************
//Name of function :  void RunPocket10 (int anum)                     //
//--------------------------------------------------------------------//
//Purpose          : This is used to run pocket 10                    //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioget(anum,chans) = is used to read the digital value from input
//		       chans (channels) of the (Pocket 10 AD)
//**********************************************************************
void RunPocket10(int anum){
     clrscr();
     gotoxy(25,2);printf("10 Bit Pocket A/D Test");
     gotoxy(25,20); printf("PRESS P to Pause, PRESS Q to Quit");
     while(1){
	gotoxy(1,3);
	clreol();
	for (chans=0; chans<11; chans++)   // 10 channels
	printf("Received Value Channel  %2d   %4.2f  \n",chans, ioget(anum,chans));
	delay(500);
	if(bioskey(1))
	 switch( toupper(getch()) ){
		case 'Q':  return;    // quit test program
		case 'P':  getch();   // pause
		 }

      }
}


//**********************************************************************
//Name of function :  void SuperAddr (void)                           //
//--------------------------------------------------------------------//
//Purpose          : This is used to select the base address          //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : void                                             //
//**********************************************************************
void SuperAddr()
{
  printf("\nNew Setting Base Address");
  printf("\n1.  0x270");
  printf("\n2.  0x260");
  printf("\n Select Base Address :  ");
   switch (getche() ) {
    case '1' :
	     ioaddr = 0x270;    // new base address
	     break;
    case '2' :
	     ioaddr = 0x260;    // new base address
	     break;
    default :
	    break;
  }
}
//**********************************************************************
//Name of function :  void ModeOperation                              //
//--------------------------------------------------------------------//
//Purpose          : This is used to select mode of operation         //
//                 :      Single-Ended = 16 channels                  //
//                 :      Differential = 8 channels                   //
//Input            : void                                             //                 :                                                  //
//Ouput            : void                                             //
//**********************************************************************
void ModeOperation()
{
 printf("\n        Mode of Operation ");
 printf("\n 1. Single-Ended (16 channels)");
 printf("\n 2. Differential (8 channels)");
 printf("\n Select number of output channels :   ");
 switch (getche() ) {
   case '1' :
	    mode = 16;
	    break;
   case '2' :
	    mode = 8;
	    break;
  default   :
	    break;
  }
 }

//**********************************************************************
//Name of function :  void RunSuper (int anum)                        //
//--------------------------------------------------------------------//
//Purpose          : This is used to run all A/D-D/A Super adapters   //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum, CHAN, count) = is used to send data to output channel  //
// ioget(anum,chans) = is used to read the digital value from input   //
//		       chans (channels) of the AIO adapters           //
//**********************************************************************
void RunSuper(int anum){
     float count = 0;
     int chan = 0;
     while(1){
	clrscr();
	printf("12/14-BIT SUPER A/D-D/A TEST PROGRAM\n");
	ioset(anum,CHAN0,count);   // send data at Channel 0
	printf("\nSend Value to Channel 1 :  %4.2f  ",count);
	ioset(anum,CHAN1,count);  // send data at Channel 1
	printf("\nSend Value to Channel 2 :  %4.2f  ",count);
	printf("\n Channel     Received Value");

	for(chan=0; chan < mode; chan++)
		printf("\n   %2d             %3.2f",chan,   (float)ioget(anum,chan) );
		printf("\n\nPRESS P to Pause,   PRESS Q to Quit");
		delay(500);
		if ( (count*10) < 100 ) count += 0.5; else count = 0.0;

			if(bioskey(1))     // function 1 returns 0 until a key is pressed
				switch( toupper(getch()) ){
					case 'Q':  return;  // wait test program
					case 'P':  getch(); // pause
				   }
			}
}
//**********************************************************************
//Name of function : void RunADDA (int anum)                          //
//--------------------------------------------------------------------//
//Purpose          : This is used to run all 12-bit A/D-D/A adapter   //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,CHAN0,count) = is used to send data to output channel 0 //
// ioget(anum,chans) = is used to read the digital value from input   //
//		       chans (channels) of the AIO adapters           //
//**********************************************************************
void RunADDA(int anum) {
   float count = 0;
   int   chan = 0;
   while(1) {
     ioset(anum, CHAN0, count);  // send data at channel 0
     clrscr();
     gotoxy(28,2);printf("12-BIT A/D D/A TEST PROGRAM");
     gotoxy(21,4);printf("   Send Value to Channel 1  :  %4.2f", count);
     gotoxy(24,5);printf("    Channel            Received Value");
     for (chan = 0; chan <16; chan++)
     {      // read data value from input port
     printf("\n                              %2d                %3.2f", chan, (float) ioget(anum,chan));
       }
     printf("\n\n PRESS P to Pause, PRESS Q to Quit");
     delay(500);
     if ( (count*10) < 90 ) count += 0.5; else count = 0.0;
			if(bioskey(1))  // function 1 returns 0 until a key is pressed
				switch( toupper(getch()) ){
					case 'Q':  return;   // quit test program
					case 'P':  getch();  // pause
				   }
     }
  }

//**********************************************************************
//Name of function : void RunAADDA (int anum)                         //
//--------------------------------------------------------------------//
//Purpose          : This is used to run all Advance 12-bit A/D-D/A   //
//		   :	adapter   				      //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,CHAN0,count) = used to send data to output channel 0    //
// ioget(anum,chans) = used to read the digital value from input      //
//		       chans (channels) of the AIO adapters           //
//**********************************************************************
void RunAADDA12(int anum){
     float count = 0;
     int chan=0;
     while(1){
	clrscr();
	gotoxy(28,2); printf(" 12-BIT ADVANCE  AD- DA ");
	ioset(anum,CHAN0,count);  // send data at Channel 0
	gotoxy(20,4);printf("Send Value to Channel 1 %4.2f  ",count);
	ioset(anum,CHAN1,count);  // send data at Channel 1
	gotoxy(20,5);printf("Send Value to Channel 2 %4.2f  ",count);
	gotoxy(20,7);printf(" Channel     Received Value");

	for(chan=0;chan<mode;chan++)  // read data at specified channel
		printf("\n                       %2d           %3.2f",chan,   (float)ioget(anum,chan) );
		printf("\n\n                  PRESS P to Pause,   PRESS Q to Quit");
		delay(500);
		if ( (count*10) < 100 ) count += 0.5; else count = 0.0;
			if(bioskey(1))  // function 1 returns 0 until a key is pressed
				switch( toupper(getch()) ){
					case 'Q':  return;   // quit the test program
					case 'P':  getch();  // pause
				   }
			}
}
//**********************************************************************
//Name of function : void RunHI12 (int anum)                          //
//--------------------------------------------------------------------//
//Purpose          : This is used to run all HI Performance 12-bit    //
//                 :    A/D-D/A adapter  adapter                      //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,CHAN0,count) = used to send data to output channel0     //
// ioget(anum,chans) = used to read the digital value from input      //
//		       chans (channels) of the AIO adapters           //
//**********************************************************************
void RunHI12(int anum){
     float count = 0;
     int chan = 0;
     while(1){
	clrscr();
	gotoxy(25,2); printf("12-BIT HIGH PERFORMANCE A/D-D/A");
	ioset(anum,CHAN0,count);  // send data at channel 0
	gotoxy(25,4);printf("\Send Value to Channel 1 :  %4.2f  ",count);
	ioset(anum,CHAN1,count);  // send data at channel 1
	gotoxy(25,5);printf("Send Value to Channel 2 :  %4.2f  ",count);
	gotoxy(25,6);printf("   Channel        Received Value");

	for(chan=0;chan<16;chan++)  // read data at input channel
		printf("\n                             %2d               %3.2f",chan,   (float)ioget(anum,chan) );
		gotoxy(24,23);printf("PRESS P to Pause,   PRESS Q to Quit");
		delay(500);

		if ( (count*10) < 100 ) count += 0.5; else count = 0.0;
			if(bioskey(1))    // function 1 returns 0 until a key is pressed
				switch( toupper(getch()) ){
					case 'Q':  return;   // quit test program
					case 'P':  getch();  // pause
				   }
			}
}
//**********************************************************************
//Name of function : void RunHI14 (int anum)                          //
//--------------------------------------------------------------------//
//Purpose          : This is used to run all HI Performance 14-bit    //
//                 :    A/D-D/A adapter  adapter                      //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,CHAN0,count) = used to send data to output channel0     //
// ioget(anum,chans) = used to read the digital value from input      //
//		       chans (channels) of the AIO adapters           //
//**********************************************************************
void RunHI14(int anum){
     float count = 0;
     int chan = 0;
     while(1){
	clrscr();
	gotoxy(25,2); printf("14-BIT HIGH PERFORMANCE A/D - D/A");
	ioset(anum,CHAN0,count);   // send data at channel 0
	gotoxy(25,4);printf("Send Value to Channel 1 :  %4.2f  ",count);
	ioset(anum,CHAN1,count);   // send data at channel 1
	gotoxy(25,5);printf("Send Value to Channel 2 :  %4.2f  ",count);
	gotoxy(25,7);printf("     Channel      Received Value");

	for(chan=0;chan<16;chan++)  // read data at input channel
		printf("\n                               %2d             %3.2f",chan,   (float)ioget(anum,chan) );
		gotoxy(25,24);printf("PRESS P to Pause,   PRESS Q to Quit");
		delay(700);
		if ( (count*10) < 100 ) count += 0.5; else count = 0.0;
			if(bioskey(1))    // function 1 returns 0 until a key is pressed
				switch( toupper(getch()) ){
					case 'Q':  return;   // quit test program
					case 'P':  getch();  // pause
				   }
			}
}
//**********************************************************************
//Name of function : void RunHI16 (int anum)                          //
//--------------------------------------------------------------------//
//Purpose          : This is used to run all HI Performance 16-bit    //
//                 :    A/D-D/A adapter  adapter                      //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,CHAN0,count) = used to send data to output channel0     //
// ioget(anum,chans) = used to read the digital value from input      //
//		       chans (channels) of the AIO adapters           //
//**********************************************************************
void RunHI16(int anum){
     float count = 0;
     int chan = 0;
     while(1){
	clrscr();
	gotoxy(25,1);printf("16-BIT HIGH PERFORMANCE A/D - D/A");
	ioset(anum,CHAN0,count);  // send data at channel 0
	gotoxy(25,3);printf("Send Value to Channel 1 :  %4.2f  ",count);
	ioset(anum,CHAN1,count);  // send data at channel 1
	gotoxy(25,4);printf("Send Value to Channel 2 :  %4.2f  ",count);
	gotoxy(25,6);printf("     Channel       Received Value");

	for(chan=0;chan<16;chan++)  //  read data at input channel
		printf("\n                               %2d             %3.2f",chan,   (float)ioget(anum,chan) );
		gotoxy(25,24);printf("PRESS P to Pause,   PRESS Q to Quit");
		delay(500);
		if ( (count*10) < 100 ) count += 0.5; else count = 0.0;
			if(bioskey(1))    // function 1 returns 0 until a key is pressed
				switch( toupper(getch()) ){
					case 'Q':  return;   // quit test program
					case 'P':  getch();  // pause
				   }
			}
}

//**********************************************************************
//Name of function : void RunDA8 (int anum)                           //
//--------------------------------------------------------------------//
//Purpose          : This is used to run 8-bit A/D 8-channel adapter  //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,CHAN0,count) = used to send data to output channel 0    //
// ioget(anum,chans) = used to read the digital value from input      //
//		       chans (channels) of the AIO adapters           //
//**********************************************************************
void RunDA8(int anum){
     float count = 0.0;
     while(1){
	clrscr();
	gotoxy(25,2);printf("8-BIT D/A 8-CHANNEL");
	ioset(anum,CHAN0,count);   // send data at channel 0
	printf("\nSend Value to Channel 0 : %4.2f  ",count);
	ioset(anum,CHAN1,count);   // send data at channel 1
	printf("\nSend Value to Channel 1 : %4.2f  ",count);
	ioset(anum,CHAN2,count);   // send data at channel 2
	printf("\nSend Value to Channel 2 : %4.2f  ",count);
	ioset(anum,CHAN3,count);   // send data at channel 3
	printf("\nSend Value to Channel 3 : %4.2f  ",count);
	ioset(anum,CHAN4,count);   // send data at channel 4
	printf("\nSend Value to Channel 4 : %4.2f  ",count);
	ioset(anum,CHAN5,count);   // send data at channel 5
	printf("\nSend Value to Channel 5 : %4.2f  ",count);
	ioset(anum,CHAN6,count);   // send data at channel 6
	printf("\nSend Value to Channel 6 : %4.2f  ",count);
	ioset(anum,CHAN7,count);   // send data at channel 7
	printf("\nSend Value to Channel 7 : %4.2f  ",count);

	printf("\n\nPRESS P to Pause,   PRESS Q to Quit");
	delay(1000);
	 if ( (count*10) < 90 ) count += 0.5; else count = 0.0;
		if(bioskey(1))   // function 1 returns 0 until a key is pressed
			switch( toupper(getch()) ){
				case 'Q':  return;   // quit test program
				case 'P': getch();   // pause
			   }
		}
}
//**********************************************************************
//Name of function : void RunDA12 (int anum)                          //
//--------------------------------------------------------------------//
//Purpose          : This is used to run 12-bit A/D 8-channel adapter //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,CHAN0,count) = used to send data to output channel 0    //
// ioget(anum,chans) = used to read the digital value from input      //
//		       chans (channels) of the AIO adapters           //
//**********************************************************************
void RunDA12(int anum){
     float count = 0.0;
     while(1){
	clrscr();
	gotoxy(25,2); printf("12-BIT D/A 8-CHANNEL");
	ioset(anum,CHAN0,count);  // send data at channel 0
	printf("\nSend Value to Channel 0 : %4.2f  ",count);
	ioset(anum,CHAN1,count);  // send data at channel 1
	printf("\nSend Value to Channel 1 : %4.2f  ",count);
	ioset(anum,CHAN2,count);  // send data at channel 2
	printf("\nSend Value to Channel 2 : %4.2f  ",count);
	ioset(anum,CHAN3,count);  // send data at channel 3
	printf("\nSend Value to Channel 3 : %4.2f  ",count);
	ioset(anum,CHAN4,count);  // send data at channel 4
	printf("\nSend Value to Channel 4 : %4.2f  ",count);
	ioset(anum,CHAN5,count);  // send data at channel 5
	printf("\nSend Value to Channel 5 : %4.2f  ",count);
	ioset(anum,CHAN6,count);  // send data at channel 6
	printf("\nSend Value to Channel 6 : %4.2f  ",count);
	ioset(anum,CHAN7,count);  // send data at channel 7
	printf("\nSend Value to Channel 7 : %4.2f  ",count);

	printf("\n\nPRESS P to Pause,   PRESS Q to Quit");
	delay(1000);
	 if ( (count*10) < 90 ) count += 0.5; else count = 0.0;
		if(bioskey(1))     // function 1 returns 0 until a key is pressed
			switch( toupper(getch()) ){
				case 'Q':  return;  // quit test program
				case 'P':  getch(); // pause
			   }
		}
}
//**********************************************************************
//Name of function : void RunDA14 (int anum)                          //
//--------------------------------------------------------------------//
//Purpose          : This is used to run 14-bit A/D 8-channel adapter //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,CHAN0,count) = used to send data to output channel 0    //
// ioget(anum,chans) = used to read the digital value from input      //
//		       chans (channels) of the AIO adapters           //
//**********************************************************************
void RunDA14(int anum){
     float count = 0.0;
     while(1){
	clrscr();
	gotoxy(25,2); printf("14-BIT D/A 8-CHANNEL");
	ioset(anum,CHAN0,count);  // send data at channel 0
	printf("\nSend Value to Channel 0 : %4.2f  ",count);
	ioset(anum,CHAN1,count);  // send data at channel 1
	printf("\nSend Value to Channel 1 : %4.2f  ",count);
	ioset(anum,CHAN2,count);  // send data at channel 2
	printf("\nSend Value to Channel 2 : %4.2f  ",count);
	ioset(anum,CHAN3,count);  // send data at channel 3
	printf("\nSend Value to Channel 3 : %4.2f  ",count);
	ioset(anum,CHAN4,count);  // send data at channel 4
	printf("\nSend Value to Channel 4 : %4.2f  ",count);
	ioset(anum,CHAN5,count);  // send data at channel 5
	printf("\nSend Value to Channel 5 : %4.2f  ",count);
	ioset(anum,CHAN6,count);  // send data at channel 6
	printf("\nSend Value to Channel 6 : %4.2f  ",count);
	ioset(anum,CHAN7,count);  // send data at channel 7
	printf("\nSend Value to Channel 7 : %4.2f  ",count);

	printf("\n\nPRESS P to Pause,   PRESS Q to Quit");
	delay(1000);
	 if ( (count*10) < 90 ) count += 0.5; else count = 0.0;
		if(bioskey(1))    // function 1 returns 0 until a key is pressed
			switch( toupper(getch()) ){
				case 'Q':  return;   // quit test program
				case 'P': getch();   // pause
			   }
		}
}


//**********************************************************************
//Name of function : char menu()                                      //
//--------------------------------------------------------------------//
//Purpose          : This is used to identify all the adapters used   //
//                 :    and user may select each adapter for testing  //
//Input            : char - specifies the adapter selected            //
//                 :                                                  //
//Ouput            : void                                             //
//**********************************************************************
char menu1(){
	char c;
	clrscr();
	gotoxy(23,2);printf("	MENU FOR AIO TEST PROGRAM ");
	gotoxy(27,4);printf("[1]  12 BIT");
	gotoxy(27,5);printf("[2]  12 BIT SUPER A/D D/A");
	gotoxy(27,6);printf("[3]  14 BIT SUPER A/D D/A");
	gotoxy(27,7);printf("[4]  12-BIT ADVANCE A/D D/A");
	gotoxy(27,8);printf("[5]  12-BIT HI PERFORMANCE A/D D/A CARD");
	gotoxy(27,9);printf("[6]  14-BIT HI PERFORMANCE A/D D/A CARD");
	gotoxy(27,10);printf("[7]  16-BIT HI PERFORMANCE A/D D/A CARD");
	gotoxy(27,11);printf("[8]  8-BIT D/A 8-CHANNEL");
	gotoxy(27,12);printf("[9]  12-BIT D/A 8-CHANNEL");
	gotoxy(27,13);printf("[A]  14-BIT D/A 8-CHANNEL");
	gotoxy(27,14);printf("[B]  10-BIT POCKET A/D");
	gotoxy(27,15);printf("[C]  12 BIT POCKET A/D");
	gotoxy(27,16);printf("[D]  GO TO MAIN MENU");
	gotoxy(27,18);printf("   Select an option ? ");
	// this loop is done if the selected option is right, however if the
	// the selected option is wrong it will prompt the user to try again
	do{
		if(bioskey(1)) {
			c = getch();
			if (c >='0' && c <='9' || c>= 'A' && c<= 'D' || c>='a' && c<= 'd') return c;
		}
	}while(1);
	return c;
}

//**********************************************************************
//Name             : void main() function                             //
//--------------------------------------------------------------------//
//Purpose          : This is used to run all HI Performance 16-bit    //
//                 :    A/D-D/A adapter  adapter                      //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : void                                             //
//**********************************************************************
// iosettype(adapter_type, ioaddr, ...)                               //
//       this function is used to specify the adapter type and the    //
//	 base address                                                 //
//       - it will return a positive integer which corresponds to     //
//         the Adapter Number                                         //
// ioinit( ) = this function is used to initialize and allocate IO    //
//             buffer.  It detects CPU speed to be linear with the    //
//             speed of the adapters.                                 //
//           = it will return a positive integer value, 1 signifies   //
//             a successful output and a return of 0 means failure.   //
// ioclose() = this function is used to deallocate the IO buffer after//
//             it has been used in the program                        //
//**********************************************************************
void test1(){
	int ADDA,AADDA12,Super12, Super14,Pocket12;
	int HIPER12, HIPER14, HIPER16, DA88, DA128;
	int DA148, Pocket10;
	clrscr();
	gotoxy(32,2);printf("CONFIGURING YOUR SYSTEM   \n\n             Please Wait...");
	ioinit(7);  // for 7 adapters, but it may vary according to users'
		   // application
	do{
		switch(menu1()){
		 case '1':    clrscr();
			printf("12 Bit A/D D/A");
			printf("\nEnter Address = " );
			ioaddr = getAddress();  // get address in hex
			// ADDA12 - set the adapter name; address and convertion table
			ADDA = iosettype(ADDA12, ioaddr, ADDA12_tab);
			RunADDA(ADDA);
			break;

		 case '2':  clrscr();
			printf("12 Bit Super A/D D/A");
			SuperAddr();     // get base address in hex
			ModeOperation(); // single-ended or differential
			// SADDA12 - set the adapter name; address and convertion table
			Super12 = iosettype(SADDA12, ioaddr, SADDA12_tab);
			RunSuper(Super12);
			break;

		 case '3':    clrscr();
			printf("14 Bit Super A/D D/A");
			SuperAddr();      // get base address in hex
			ModeOperation();  // single-ended or differential
			// SADDA14 - set adapter name; address and convertion table
			Super14 = iosettype(SADDA14, ioaddr, SADDA14_tab);
			RunSuper(Super14);
			break;

		 case '4':  clrscr();
			printf("12 BIT Advance A/D D/A");
			printf("\nEnter Address = " );
			ioaddr = getAddress();  // get the base address in hex
			ModeOperation();        // single-ended or differential
			// AADDA - set the adapter name; address and convertion table
			AADDA12 = iosettype(AADDA, ioaddr, AADDA12_tab);
			RunAADDA12(AADDA12);
			break;

		 case '5' : clrscr();
			printf("12-BIT HI PERFORMANCE TEST PROGRAM");
			printf("\nEnter Address  = ");
			ioaddr = getAddress();  // get the base address in hex
			// HADDA12 - set the adapter name; address and convertion table
			HIPER12 = iosettype(HADDA12, ioaddr, HIADDA12_tab);
			RunHI12(HIPER12);
			break;

		 case '6' : clrscr();
			printf("14-BIT HI PERFORMANCE TEST PROGRAM");
			printf("\nEnter Address  = ");
			ioaddr = getAddress();  // get the base address in hex
			// HADDA14 - set the adapter name; address and convertion table
			HIPER14 = iosettype(HADDA14, ioaddr, HIADDA14_tab);
			RunHI14(HIPER14);
			break;

		 case '7' :  clrscr();
			printf("16-BIT HI PEFFORMANCE TEST PROGRAM");
			printf("\nEnter Address = ");
			ioaddr = getAddress();  // get the base address in hex
			// HADDA16 - set the adapter name; address and convertion table
			HIPER16 = iosettype(HADDA16, ioaddr, HIADDA16_tab);
			RunHI16(HIPER16);
			break;

		 case '8' :    clrscr();
			printf("8-BIT D/A 8-CHANNEL TEST PROGRAM");
			printf("\nEnter Address = ");
			ioaddr = getAddress();   // get the base address in hex
			// DA8 - set the adapter name; address and convertion table
			DA88 = iosettype(DA8, ioaddr, DA8_tab);
			RunDA8(DA88);
			break;

		 case '9' :  clrscr();
			printf("12-BIT D/A 8-CHANNEL TEST PROGRAM");
			printf("\nEnter Address = ");
			ioaddr = getAddress();  // get the base address in hex
			// DA12 - set the adapter name; address and convertion table
			DA128 = iosettype(DA12, ioaddr, DA12_tab);
			RunDA12(DA128);
			break;

		 case 'a' :
		 case 'A' :    clrscr();
			printf("14-BIT D/A 8-CHANNEL TEST PROGRAM");
			printf("\nEnter Address = ");
			ioaddr = getAddress();  // get the base address in hex
			// DA14 - set the adapter name; address and convertion table
			DA148 = iosettype(DA14, ioaddr, DA14_tab);
			RunDA14(DA148);
			break;

		 case 'b' :
		 case 'B' :    clrscr();
			printf("10 Bit Pocket A/D");
			printf("\nEnter Box ID (0..F) = " );
			ioaddr = getAddress(); // get the box ID in hex
			printf("\nEnter Printer Port");  // select address of printer port
			printf("\n      [0]  LPT1");     // 0x3bc
			printf("\n      [1]  LPT2");     // 0x378
			printf("\n      [2]  LPT3");     // 0x278
			printf("\n Select  Print Port [0..2] ? ");
			switch(getch()){
			 case '0' : LPT_ADDR = LPT1;
				    break;
			 case '1' : LPT_ADDR = LPT2;
				    break;
			 case '2' : LPT_ADDR = LPT3;
				}
			// PAD10 - set the pocket name; id; and convertion table
			Pocket10 = iosettype(PAD10,ioaddr,PAD10_tab);
			RunPocket10(Pocket10);
			break;

		 case 'c':
		 case 'C':
			clrscr();
			printf("12 Bit Pocket A/D");
			printf("\nEnter Box ID (0..F) = " );
			ioaddr = getAddress(); // get the box id in hex
			printf("\nEnter Printer Port"); // select printer port address
			printf("\n      [0]  LPT1");    // 0x3bc
			printf("\n      [1]  LPT2");    // 0x378
			printf("\n      [2]  LPT3");    // 0x278
			printf("\n Select  Print Port [0..2] ? ");

			switch(getch()){
			 case '0' : LPT_ADDR = LPT1;
					break;
			 case '1' : LPT_ADDR = LPT2;
					break;
			 case '2' : LPT_ADDR = LPT3;
					break;
				}
			// PAD12 - set the adapter name; addressa and convertion table
			Pocket12 = iosettype(PAD12,ioaddr,PAD12_tab);
			RunPocket12(Pocket12);
			break;

		  case 'd':
		  case 'D':
			ioclose(); // set the system's memory/buffer allocation
				   // to its normal size after using the
				   // I/O adapters
			return;
			 }

		}while(1);
} // test1