//************************************************************************
// Name of Program : TEST2.C                                            //
//************************************************************************
// Purpose         : This program is created to apply and test the     //
//                 : "io.h" and "io.lib" for DIO adapters.             //
//*************************************************************************

#include <dos.h>
#include <conio.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
int ioaddr;    // specify the base address in hex
int portno;    // specify the port number used

//**********************************************************************
//Name of function :  void RunPhoto (int anum)                        //
//--------------------------------------------------------------------//
//Purpose          : This is used to run 8 Photo 8 Relay              //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,PORT0,count) = used send data at output port 0
// ioget(anum,PORT1) = specifies to read the digital value from input
//		       port of the adapter
//**********************************************************************
void RunPhoto(int anum){
    int count = 1;
    clrscr();
    printf("8 Photo 8 Relay Test");
    gotoxy(1,20); printf("PRESS P to Pause, PRESS Q to Quit");
    while(1){
	gotoxy(1,3);
	clreol();
	ioset(anum,PORT0,count); // send data at Port 0
	delay(10);
	// ioget (anum, PORT1)  used to read data at input Port 1
	printf("\nSend Value Channel 0 %4d  Received  Value %4d",count,(int)ioget(anum,PORT1));
	 if(count<0x80) count <<= 1; else count = 1;
	   delay(700);
	    if(bioskey(1))  // function 1 returns 0 until a key is pressed
	      switch( toupper(getch()) ){
		case 'Q':  return;   // quit test program
		case 'P':  getch();  // pause
		 }
	 }
}

//**********************************************************************
//Name of function :  void Run16Photo (int anum)                      //
//--------------------------------------------------------------------//
//Purpose          : This is used to run 16 Photo                     //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,PORT0,count) = used send data at output port 0
// ioget(anum,PORT1) = used to read the digital value from input
//		       port of the adapter
//**********************************************************************
void Run16Photo(int anum){
    unsigned count = 1;
    unsigned long value;
    clrscr();
    printf("16 Photo 16 Relay Test");
    gotoxy(1,20); printf("PRESS P to Pause, PRESS Q to Quit");
    while(1){
	gotoxy(1,3);
	clreol();
	ioset(anum,PORT0,(count & 0x00FF));  	   // for low bit
	ioset(anum,PORT1,(count & 0xFF00) >> 8);   // for high bit
	delay(10);
	value = (unsigned)ioget(anum, PORT1);      // read input data
	value = value << 8;                        // shift data to left
	value = value | (unsigned)ioget(anum, PORT0);
	printf("\nSend Value PORT 1 %7u  Received  Value %7lu",count,value);

	 if(count<32768) count <<=1; else count = 1;
	   delay(500);
	    if(bioskey(1))   // function 1 returns 0 until a key is pressed
	      switch( toupper(getch()) ){
		case 'Q':  return;   // quit test program
		case 'P':  getch();  // pause
		 }
	 }
}
//**********************************************************************
//Name of function :  void RunTTL (int anum)                          //
//--------------------------------------------------------------------//
//Purpose          : This is used to run TTL I/O card                 //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,PORT0,count) = used send data at output port 0
// ioget(anum,PORT1) = used to read the digital value from input
//		       port of the adapter
//**********************************************************************
void RunTTL(int anum){
    int count = 1;
    clrscr();
    printf("TTL I/O TEST PROGRAM");
    gotoxy(1,20); printf("PRESS P to Pause, PRESS Q to Quit");
    while(1){
	gotoxy(1,3);
	clreol();
	  ioset(anum,PORT0,count);
	  printf("\nSend Value  PORT 0   %4d  Received  Value %4d",count,(int)ioget(anum,PORT0));
	  ioset(anum,PORT1,count);
	  printf("\nSend Value  PORT 1   %4d  Received  Value %4d",count,(int)ioget(anum,PORT1));
	  ioset(anum,PORT2,count);
	  printf("\nSend Value  PORT 2   %4d  Received  Value %4d",count,(int)ioget(anum,PORT2));
	  ioset(anum,PORT3,count);
	  printf("\nSend Value  PORT 3   %4d  Received  Value %4d",count,(int)ioget(anum,PORT3));
	  ioset(anum,PORT4,count);
	  printf("\nSend Value  PORT 4   %4d  Received  Value %4d",count,(int)ioget(anum,PORT4));
	  ioset(anum,PORT5,count);
	  printf("\nSend Value  PORT 5   %4d  Received  Value %4d",count,(int)ioget(anum,PORT5));
	  ioset(anum,PORT6,count);
	  printf("\nSend Value  PORT 6   %4d  Received  Value %4d",count,(int)ioget(anum,PORT6));
	  ioset(anum,PORT7,count);
	  printf("\nSend Value  PORT 7   %4d  Received  Value %4d",count,(int)ioget(anum,PORT7));

	if(count<0x80) count <<=1; else count = 1;
	   delay(500);
	    if(bioskey(1))     // function 1 returns 0 until a key is pressed
	      switch( toupper(getch()) ){
		case 'Q':  return;  // quit test program
		case 'P':  getch(); // pause
		 }
	 }
}
//**********************************************************************
//Name of function :  void RunPhoto (int anum)                        //
//--------------------------------------------------------------------//
//Purpose          : This is used to run 8 Photo 8 Relay              //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,PORT0,count) = used send data at output port 0
// ioget(anum,PORT1) = specifies to read the digital value from input
//		       port of the adapter
//**********************************************************************
void RunIndus8(int anum){
    int count = 1;
    clrscr();
    printf("INDUSTRIAL 8-BIT TEST PROGRAM");
    gotoxy(1,20); printf("PRESS P to Pause, PRESS Q to Quit");
    while(1){
	gotoxy(1,3);
	clreol();
	ioset(anum,PORT0,count);
	printf("\nSend Value  PORT 0   %4d  Received  Value %4d",count,(int)ioget(anum,PORT0));
	ioset(anum,PORT1,count);
	printf("\nSend Value  PORT 1   %4d  Received  Value %4d",count,(int)ioget(anum,PORT1));
	ioset(anum,PORT2,count);
	printf("\nSend Value  PORT 2   %4d  Received  Value %4d",count,(int)ioget(anum,PORT2));
	ioset(anum,PORT3,count);
	printf("\nSend Value  PORT 3   %4d  Received  Value %4d",count,(int)ioget(anum,PORT3));
	ioset(anum,PORT4,count);
	printf("\nSend Value  PORT 4   %4d  Received  Value %4d",count,(int)ioget(anum,PORT4));
	ioset(anum,PORT5,count);
	printf("\nSend Value  PORT 5   %4d  Received  Value %4d",count,(int)ioget(anum,PORT5));
	ioset(anum,PORT6,count);
	printf("\nSend Value  PORT 6   %4d  Received  Value %4d",count,(int)ioget(anum,PORT6));
	ioset(anum,PORT7,count);
	printf("\nSend Value  PORT 7   %4d  Received  Value %4d",count,(int)ioget(anum,PORT7));

	 if(count<0x80) count <<=1; else count = 1;
	   delay(500);
	    if(bioskey(1))   // function 1 returns 0 until a key is pressed
	      switch( toupper(getch()) ){
		case 'Q':  return;   // quit test program
		case 'P':  getch();  // pause
		 }
	 }
}
//**********************************************************************
//Name of function :  void RunIndus16 (int anum)                      //
//--------------------------------------------------------------------//
//Purpose          : This is used to run 16 Industrial card           //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,PORT0,count) = used send data at output port 0
// ioget(anum,PORT1) = used to read the digital value from input
//		       port of the adapter
//**********************************************************************
void RunIndus16(int anum)
{
    unsigned count = 1;
    clrscr();
    printf("INDUSTRIAL 16-BIT TEST PROGRAM");
    gotoxy(1,20); printf("PRESS P to Pause, PRESS Q to Quit");
    while(1){
	gotoxy(1,3);
	clreol();
	ioset(anum,PORT0,(unsigned)count);
	printf("\nSend Value PORT 0 %7u   Received Value  %7u",(unsigned)count, (unsigned long)ioget(anum,PORT0));
   /*	printf("\nSend Value PORT 1 %7u   Received Value  %7u",(unsigned)count, (unsigned long)ioget(anum,PORT1));
	printf("\nSend Value PORT 2 %7u   Received Value  %7u",(unsigned)count, (unsigned long)ioget(anum,PORT2));
	printf("\nSend Value PORT 3 %7u   Received Value  %7u",(unsigned)count, (unsigned long)ioget(anum,PORT3));
	printf("\nSend Value PORT 4 %7u   Received Value  %7u",(unsigned)count, (unsigned long)ioget(anum,PORT4));
	printf("\nSend Value PORT 5 %7u   Received Value  %7u",(unsigned)count, (unsigned long)ioget(anum,PORT5));
	printf("\nSend Value PORT 6 %7u   Received Value  %7u",(unsigned)count, (unsigned long)ioget(anum,PORT6));
	printf("\nSend Value PORT 7 %7u   Received Value  %7u",(unsigned)count, (unsigned long)ioget(anum,PORT7));
 */
	if(count < 32768 ) count <<=1; else count = 1;

	   delay(700);
	    if(bioskey(1))    // function 1 returns 0 until a key is pressed
	      switch( toupper(getch()) ){
		case 'Q':  return;   // quit test program
		case 'P':  getch();  // pause
		 }
	 }
}

//**********************************************************************
//Name of function :  void RunPocketDIO (int anum)                    //
//--------------------------------------------------------------------//
//Purpose          : This is used to run Pocket DIO                   //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,PORT0,count) = used send data at output port 0
// ioget(anum,PORT1) = used to read the digital value from input
//		       port of the adapter
//**********************************************************************
void RunPocketDIO(int anum){
    int count = 1;
    clrscr();
    printf("8 Bit Pocket DIOTest");
    gotoxy(1,15); printf("PRESS P to Pause, PRESS Q to Quit");
    while(1){
	gotoxy(1,3);
	clreol();
	ioset(anum,PORT0,count);  // send data at output port
	printf("\nSend Value   %4d  Received Value %4d", count,(int)ioget(anum,PORT0));
	 if(count<0x80) count <<=1; else count = 1;
	  delay(500);
	   if(bioskey(1))   // function 1 returns 0 until a key is pressed
	     switch( toupper(getch()) ){
		case 'Q':  return;  // quit test program
		case 'P':  getch(); // pause
	   }
	 }
}
//**********************************************************************
//Name of function :  void RunPocketDI16 (int anum)                   //
//--------------------------------------------------------------------//
//Purpose          : This is used to run pocket DI 16-bit             //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioget(anum,PORT0) = used to read the digital value from input
//		       port of the adapter
//**********************************************************************
void RunPocketDI16(int anum){
    long x;
    clrscr();
    printf("POCKET DI 16-BIT PROGRAM TEST");
    gotoxy(1,15); printf("PRESS P to Pause, PRESS Q to Quit");
    while(1){
	gotoxy(1,3);
	clreol();
	x = (long)ioget(anum,PORT0);
	if (x<0) x = 65536L+x;   // convert x to unsigned long integer
	printf("\nReceived Value  %7ld",x );
	  delay(500);
	   if(bioskey(1))    // function 1 returns 0 until a key is pressed
	     switch( toupper(getch()) ){
		case 'Q':  return;   // quit test program
		case 'P':  getch();  // pause
	   }
	 }
}
//**********************************************************************
//Name of function :  void RunPocketDO16 (int anum)                   //
//--------------------------------------------------------------------//
//Purpose          : This is used to run Pocket DO 16-bit             //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,PORT0,count) = used send data at output port 0
//**********************************************************************
void RunPocketDO16(int anum){
    int unsigned count = 1;
    clrscr();
    printf("POCKET DO 16-BIT PROGRAM TEST");
    gotoxy(1,15); printf("PRESS P to Pause, PRESS Q to Quit");
    while(1){
	gotoxy(1,3);
	clreol();
	ioset(anum,PORT0,count);
	printf("\nSend Value  %7d", count);
	 if(count<32768) count <<=1; else count = 1;
	  delay(500);
	   if(bioskey(1))   // function 1 returns 0 until a key is pressed
	     switch( toupper(getch()) ){
		case 'Q':  return;   // quit test program
		case 'P':  getch();  // pause
	   }
	 }
}

//**********************************************************************
//Name of function :  void Run8255 (int anum)                         //
//--------------------------------------------------------------------//
//Purpose          : This is used to run the 8255 I/O card            //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,PORT0,count) = used send data at output port
// ioget(anum,PORT3) = used to read data at input port
//**********************************************************************
void Run8255(int anum){
    int count = 1;
    int z = 0;
    clrscr();
    printf("8255/8253 I/O CARD TEST PROGRAM");
    gotoxy(1,20); printf("PRESS P to Pause, PRESS Q to Quit");
    while(1){
	gotoxy(1,3);
	clreol();
      if (z == 0){
	ioset(anum,PORT0,count);
	printf("\nSend Value PORT 0 %4d  Received  Value PORT 3 %4d",count,(unsigned)ioget(anum,PORT3));
	ioset(anum,PORT1,count);
	printf("\nSend Value PORT 1 %4d  Received  Value PORT 4 %4d",count,(unsigned)ioget(anum,PORT4));
	ioset(anum,PORT2,count);
	printf("\nSend Value PORT 2 %4d  Received  Value PORT 5 %4d",count,(unsigned)ioget(anum,PORT5));
	if (count == 0x80)
	   z = 1;
      } else {

	ioset(anum,PORT3,count);
	printf("\nSend Value PORT 3 %4d  Received  Value PORT 0 %4d",count,(int)ioget(anum,PORT0));
	ioset(anum,PORT4,count);
	printf("\nSend Value PORT 4 %4d  Received  Value PORT 1 %4d",count,(int)ioget(anum,PORT1));
	ioset(anum,PORT5,count);
	printf("\nSend Value PORT 5 %4d  Received  Value PORT 2 %4d",count,(int)ioget(anum,PORT2));
	if (count == 0x80)
	  z = 0;
       }
	 if(count<0x80) count <<= 1; else count = 1;

	   delay(500);
	    if(bioskey(1))   // function 1 returns 0 until a key is pressed
	      switch( toupper(getch()) ){
		case 'Q':  return;  // quit test program
		case 'P':  getch(); // pause
		 }
	 }
}
//**********************************************************************
//Name of function :  void RunM8255 (int anum)                        //
//--------------------------------------------------------------------//
//Purpose          : This is used to run the Multi 8255 I/O card      //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : Returns a positive integer which corresponds to  //
//                 : the adapter number.                              //
//**********************************************************************
// ioset(anum,PORT0,count) = used send data at output port
// ioget(anum,PORT1) = used to read the digital value from input
//		       port of the adapter
//**********************************************************************
void RunM8255(int anum){
    int count = 1;
    int z = 0;
    clrscr();
    printf("MULTI 8255/8253 I/O CARD TEST PROGRAM");
    gotoxy(1,23); printf("PRESS P to Pause, PRESS Q to Quit");
    while(1){
	gotoxy(1,3);
	clreol();
    if (z == 0) {
	ioset(anum,PORT0,count);
	printf("\nSend Value PORT 00 %4d  Received  Value PORT 12 %4d",count,(int)ioget(anum,PORT12));
	ioset(anum,PORT1,count);
	printf("\nSend Value PORT 01 %4d  Received  Value PORT 13 %4d",count,(int)ioget(anum,PORT13));
	ioset(anum,PORT2,count);
	printf("\nSend Value PORT 02 %4d  Received  Value PORT 14 %4d",count,(int)ioget(anum,PORT14));
	ioset(anum,PORT3,count);
	printf("\nSend Value PORT 03 %4d  Received  Value PORT 15 %4d",count,(int)ioget(anum,PORT15));
	ioset(anum,PORT4,count);
	printf("\nSend Value PORT 04 %4d  Received  Value PORT 16 %4d",count,(int)ioget(anum,PORT16));
	ioset(anum,PORT5,count);
	printf("\nSend Value PORT 05 %4d  Received  Value PORT 17 %4d",count,(int)ioget(anum,PORT17));
	ioset(anum,PORT6,count);
	printf("\nSend Value PORT 06 %4d  Received  Value PORT 18 %4d",count,(int)ioget(anum,PORT18));
	ioset(anum,PORT7,count);
	printf("\nSend Value PORT 07 %4d  Received  Value PORT 19 %4d",count,(int)ioget(anum,PORT19));
	ioset(anum,PORT8,count);
	printf("\nSend Value PORT 08 %4d  Received  Value PORT 20 %4d",count,(int)ioget(anum,PORT20));
	ioset(anum,PORT9,count);
	printf("\nSend Value PORT 09 %4d  Received  Value PORT 21 %4d",count,(int)ioget(anum,PORT21));
	ioset(anum,PORT10,count);
	printf("\nSend Value PORT 10 %4d  Received  Value PORT 22 %4d",count,(int)ioget(anum,PORT22));
	ioset(anum,PORT11,count);
	printf("\nSend Value PORT 11 %4d  Received  Value PORT 23 %4d",count,(int)ioget(anum,PORT23));
	if (count == 0x80)
	   z = 1;
     } else {
	ioset(anum,PORT12,count);
	printf("\nSend Value PORT 12 %4d  Received  Value PORT  0 %4d",count,(int)ioget(anum,PORT0));
	ioset(anum,PORT13,count);
	printf("\nSend Value PORT 13 %4d  Received  Value PORT  1 %4d",count,(int)ioget(anum,PORT1));
	ioset(anum,PORT14,count);
	printf("\nSend Value PORT 14 %4d  Received  Value PORT  2 %4d",count,(int)ioget(anum,PORT2));
	ioset(anum,PORT15,count);
	printf("\nSend Value PORT 15 %4d  Received  Value PORT  3 %4d",count,(int)ioget(anum,PORT3));
	ioset(anum,PORT16,count);
	printf("\nSend Value PORT 16 %4d  Received  Value PORT  4 %4d",count,(int)ioget(anum,PORT4));
	ioset(anum,PORT17,count);
	printf("\nSend Value PORT 17 %4d  Received  Value PORT  5 %4d",count,(int)ioget(anum,PORT5));
	ioset(anum,PORT18,count);
	printf("\nSend Value PORT 18 %4d  Received  Value PORT  6 %4d",count,(int)ioget(anum,PORT6));
	ioset(anum,PORT19,count);
	printf("\nSend Value PORT 19 %4d  Received  Value PORT  7 %4d",count,(int)ioget(anum,PORT7));
	ioset(anum,PORT20,count);
	printf("\nSend Value PORT 20 %4d  Received  Value PORT  8 %4d",count,(int)ioget(anum,PORT8));
	ioset(anum,PORT21,count);
	printf("\nSend Value PORT 21 %4d  Received  Value PORT  9 %4d",count,(int)ioget(anum,PORT9));
	ioset(anum,PORT22,count);
	printf("\nSend Value PORT 22 %4d  Received  Value PORT 10 %4d",count,(int)ioget(anum,PORT10));
	ioset(anum,PORT23,count);
	printf("\nSend Value PORT 23 %4d  Received  Value PORT 11 %4d",count,(int)ioget(anum,PORT11));
	if (count == 0x80)
	   z = 0;
     }
	 if(count<0x80) count <<= 1; else count = 1;
	   delay(500);
	    if(bioskey(1))    // function 1 returns 0 until a key is pressed
	      switch( toupper(getch()) ){
		case 'Q':  return;  // quit test program
		case 'P':  getch(); // pause
		 }
	 }
}



//**********************************************************************
//Name of function : char menu()                                      //
//--------------------------------------------------------------------//
//Purpose          : This is used to identify all the adapters used   //
//                 :    and user may select each adapter for testing  //
//Input            : char - specifies the adapter selected            //
//                 :                                                  //
//Ouput            : void                                             //
//**********************************************************************
char menu(){
	char c;
	clrscr();
	gotoxy(25,2);printf("   DIO TEST PROGRAM ");
	gotoxy(25,4);printf("[0]  8255 8-BIT");
	gotoxy(25,5);printf("[1]  MULTI-8255");
	gotoxy(25,6);printf("[2]  TTL 8-BIT I/O");
	gotoxy(25,7);printf("[3]  INDUSTRIAL 8-BIT");
	gotoxy(25,8);printf("[4]  INDUSTRIAL 16-BIT");
	gotoxy(25,9);printf("[5]  8 PHOTO / 8 RELAY");
	gotoxy(25,10);printf("[6]  16 PHOTO / 16 RELAY");
	gotoxy(25,11);printf("[7]  POCKET DIO 8-CHANNEL");
	gotoxy(25,12);printf("[8]  POCKET DI 16 CHANNEL");
	gotoxy(25,13);printf("[9]  POCKET DO 16 CHANNEL");
	gotoxy(25,14);printf("[X]  GO TO MAIN MENU");
	gotoxy(25,16);printf("   Select option   ? ");
	do{
	   // this loop is done if the selected option is right, however if the
	   // the selected option is wrong it will prompt the user to try again

		if(bioskey(1)) {
			c = getch();
			if (c >='0' && c <='9' || c >= 'X' && c <= 'x') return c;
		}

	}while(1);
	return c;
}
//**********************************************************************
//Name             : void main() function                             //
//--------------------------------------------------------------------//
//Purpose          : This is used to run all HI Performance 16-bit    //
//                 :    A/D-D/A adapter  adapter                      //
//Input            : void                                             //
//                 :                                                  //
//Ouput            : void                                             //
//**********************************************************************
// iosettype(adapter_type, ioaddr, ...)                               //
//       this function is used to specify the adapter type and the    //
//	 base address                                                 //
//       - it will return a positive integer which corresponds to     //
//         the Adapter Number                                         //
// ioinit( ) = this function is used to initialize and allocate IO    //
//             buffer.  It detects CPU speed to be linear with the    //
//             speed of the adapters.                                 //
//           = it will return a positive integer value, 1 signifies   //
//             a successful output and a return of 0 means failure.   //
// ioclose() = this function is used to deallocate the IO buffer after//
//             it has been used in the program
//**********************************************************************
void test2(){
     int Photo,PocketDIO;
     int Photo16, TTLIO;
     int INDUS8, INDUS16, DI16, DO16;
     int S8255, MULTI8255;
     clrscr();
     gotoxy(24,2);printf("CONFIGURING YOUR SYSTEM     \n\n     Please Wait...");
     ioinit(7);
     do{
	switch(menu()){
	 case '0':    clrscr();
		printf("8255/8253 I/O CARD TEST PROGRAM ");
		printf("\nEnter Address = " );
		ioaddr = getAddress();  // get the base address in hex
		// iosettype - set the adapter name and address
		S8255 = iosettype(_8255,ioaddr);
		Run8255(S8255);
		break;

	 case '1':    clrscr();
		printf("MULTI 8255/8253 I/O CARD TEST PROGRAM ");
		printf("\nEnter Address = " );
		ioaddr = getAddress(); // get the base address in hex
		// iosettype - set the adapter name aand address
		MULTI8255 = iosettype(M8255,ioaddr);
		RunM8255(MULTI8255);
		break;

	 case '2':    clrscr();
		printf("TTL 8-BIT I/O ");
		printf("\nEnter Address = " );
		ioaddr = getAddress(); // get the base address in hex
		// iosettype - set the adapter name and address
		TTLIO = iosettype(TTL,ioaddr);
		RunTTL(TTLIO);
		break;

	 case '3':    clrscr();
		printf("INDUSTRIAL 8-BIT I/O ");
		printf("\nEnter Address = " );
		ioaddr = getAddress();   // get the base address in hex
		// iosettype - set the adapter name and address
		INDUS8 = iosettype(INDUST8,ioaddr);
		RunIndus8(INDUS8);
		break;

	 case '4':    clrscr();
		printf("INDUSTRIAL 16-BIT I/O ");
		printf("\nEnter Address = " );
		ioaddr = getAddress(); // get the abse address in hex
		// iosettype - set the adapter name and address
		INDUS16 = iosettype(INDUST16,ioaddr);
		RunIndus16(INDUS16);
		break;

	 case '5':    clrscr();
		printf("8 Photo 8 Relay");
		printf("\nEnter Address = " );
		ioaddr = getAddress();   // get the base address in hex
		// iosettype - set the adapter name and address
		Photo = iosettype(TTL,ioaddr);
		RunPhoto(Photo);
		break;

	   case '6':    clrscr();
		printf("16 Photo 16 Relay");
		printf("\nEnter Address = " );
		ioaddr = getAddress(); // get the base address in hex
		// iosettype - set the adapter name and address
		Photo16 = iosettype(TTL,ioaddr);
		Run16Photo(Photo16);
		break;


	 case '7':
		clrscr();
		printf("8 Bit Pocket DIO");
		printf("\nEnter Box ID = " );
		ioaddr = getAddress(); // set the box id in hex
		printf("\nEnter Printer Port");
		printf("\n      [0]  LPT1"); // 0x3bc
		printf("\n      [1]  LPT2"); // 0x378
		printf("\n      [2]  LPT3"); // 0x278
		printf("\n Select  Print Port [0..2] ? ");
		switch(getch()){
		 case '0' : LPT_ADDR = LPT1;
			    break;
		 case '1' : LPT_ADDR = LPT2;
			    break;
		 case '2' : LPT_ADDR = LPT3;
			    break;
		}
		// iosettype -set the adapter name and address
		PocketDIO = iosettype(PDIO8,ioaddr);
		RunPocketDIO(PocketDIO);
		break;

	 case '8':
		clrscr();
		printf("POCKET DI 16-BIT TEST PROGRAM");
		printf("\nEnter Box ID = " );
		ioaddr = getAddress();   // set the box id in hex
		printf("\nEnter Printer Port");
		printf("\n      [0]  LPT1");    // 0x3bc
		printf("\n      [1]  LPT2");    // 0x378
		printf("\n      [2]  LPT3");    // 0x278
		printf("\n Select  Print Port [0..2] ? ");
		switch(getch()){
		 case '0' : LPT_ADDR = LPT1;
				break;
		 case '1' : LPT_ADDR = LPT2;
				break;
		 case '2' : LPT_ADDR = LPT3;
				break;
		}
		// iosettype - set the adapter name and address
		DI16 = iosettype(PDI16,ioaddr);
		RunPocketDI16(DI16);
		break;

	 case '9':
		clrscr();
		printf("POCKET DO 16-BIT TEST PROGRAM");
		printf("\nEnter Box ID = " );
		ioaddr = getAddress();   // set the box id in hex
		printf("\nEnter Printer Port");
		printf("\n      [0]  LPT1");  // 0x3bc
		printf("\n      [1]  LPT2");  // 0x378
		printf("\n      [2]  LPT3");  // 0x278
		printf("\n Select  Print Port [0..2] ? ");
		switch(getch()){
		 case '0' : LPT_ADDR = LPT1;
				break;
		 case '1' : LPT_ADDR = LPT2;
				break;
		 case '2' : LPT_ADDR = LPT3;
				break;
		}
		// iosettype - set the adapter name and address
		DO16 = iosettype(PDO16,ioaddr);
		RunPocketDO16(DO16);
		break;

	 case 'x':
	 case 'X':
		// ioclose() is used to  deallocate the IO buffer
		// a return value of void or null
		ioclose();
		return;
	     }

		}while(1);
} //test2