
{ Pocket A/D Converter: Sample Program }
uses
  Crt,
  Dos;

const
{ 12 (or 10) bits resolution }
  RESOLUTION = 12;
  LPT1 = $3BC;
  LPT2 = $378;
  LPT3 = $278;

{ I/O ports for printer interface }
  DATA    = 0;
  STATUS  = 1;
  CONTROL = 2;

{ definition of each data bit }
  D7 = $80;
  D6 = $40;
  D5 = $20;
  D4 = $10;
  D3 = $08;
  D2 = $04;
  D1 = $02;
  D0 = $01;

{ definition of status port }
  BUSY     = $80;
  ACK      = $40;
  PAPEROUT = $20;
  SELECTED = $10;
  ERROR    = $08;

{ definition of control port }
  IRQENABLE = $10;
  SELECT    = $08;
  RESET     = $04;
  LF        = $02;
  STROBE    = $01;

{ pin assignments for Pocket A/D converter     }
{ ADDR     : box ID                            }
{ CLK      : clock for serial data in and out  }
{ DATAIN   : data in (from host to box)        }
{ DATAOUTO : data out (from box to host)       }
{ EOC      : end of coversion                  }
  IDMASK  = D7 or D6 or D5 or D4;
  CLK     = D1;
  DATAIN  = D2;
  DATAOUT = SELECTED;
  EOC     = ERROR;
  LPTTAB : array[1..3] of integer = (LPT1, LPT2, LPT3);
var
  port_value : byte;
  port_addr : integer;

  lpt : integer;
  addr : integer;
  box : array[0..7] of integer;
  boxno, bi, channel, i, runstate : integer;
  loopcount : longint;
  c : char;

{ udelay : delay routine }
{ n      : loop count    }
procedure udelay (n : integer);
var
  i,j : integer;
begin
  for i := 1 to n do
    for j := 1 to 100 do;
end;

{ cursoroff : hide cursor }
procedure cursoroff;
  var
    r : registers;
begin
  r.ah := 1;
  r.ch := $20;
  intr($10,r);
end;

{ cursoron : show cursor }
procedure cursoron;
  var
    r : registers;
begin
  r.ah := 1;
  r.ch := 11;
  r.cl := 12;
  intr($10,r);
end;

{ writehex: print hexdecimal value }
procedure writehex(n : word);
var
  s : string[4];
  i,z : integer;
begin
  s[0] := #4;
  for i := 4 downto 1 do
  begin
    z := n mod 16;
    n := n div 16;
    if z > 9 then s[i] := chr(ord('A') + z - 10)
    else s[i] := chr(ord('0') + z);
  end;
  write(s);
end;

{ adinit : initial A/D converter       }
{ addr   : I/O address of printer port }
procedure adinit(addr : integer);
begin
  port_addr := addr;
  port_value := 0;
end;

{ getad2  : kernel of A/D conversion routine }
{ next_ch : the channel which data           }
{           will be retrived next            }
{ return  : the A/D value                    }
function getad2(next_ch : integer) : integer;
var
  i, ad : integer;
  x : byte;
begin
  { wait for EOC (end of conversion) }
  { timeout = 500 ms                 }
  for i := 1 to 1000 do
    if (port[STATUS + port_addr] and EOC) > 0 then break;
  if (port[STATUS + port_addr] and EOC) = 0 then
    getad2 := -1;

  { start retriving data and set next channel }
  ad := 0;
  for i := 1 to RESOLUTION do
  begin
    if (i <= 4) and ((next_ch and ($08 shr (i - 1))) > 0) then
      x := port_value or DATAIN
    else
      x := port_value;
    port[DATA + port_addr] := x;
    ad := ad shl 1;
    if (port[STATUS + port_addr] and DATAOUT) > 0 then
      Inc(ad);
    port[DATA + port_addr] := x or CLK;
    udelay (1);
    port[DATA + port_addr] := x;
    udelay (1);
  end;
  getad2 := ad;
end;

{ getad   : get A/D value }
{ box     : box ID        }
{ channel : A/D channel   }
function getad(box : integer; channel : integer) : integer;
const
  prev_channel : integer = 0;
  prev_box : integer = -1;
var
  newflag : integer;
begin
  if box <> prev_box then
  begin
    prev_box := box;
    port_value := box shl 4;
    port[DATA + port_addr] :=  port_value;
    udelay (100);
    newflag := 1;
  end;
  if channel <> prev_channel then
  begin
    prev_channel := channel;
    newflag := 1;
  end;
  if newflag > 0 then
    getad2 (channel);
  getad := getad2 (channel);
end;

begin
  loopcount := 0;
  lpt := 1;
  addr := LPTTAB[lpt];
  boxno := 1;
  for i := 0 to 7 do
    box[i] := i;
  clrscr;
  cursoroff;
  gotoxy (25, 2);
  write ('Pocket A/D Converter Test Program V1.0');
  gotoxy (1, 25);
  write ('   [L]: LPT   [1-8]: BOXID   [G]: GO   [S]: STOP   [Q]: QUIT  [0]: BOXNO ');
  for channel := 0 to 10 do
  begin
    gotoxy (10, 10 + channel);
    write (channel + 1:2);
  end;
  gotoxy (10, 21);
  write ('Ref');
  gotoxy (10, 22);
  write ('Ref-');
  gotoxy (10, 23);
  write ('Ref+');
  gotoxy (10, 4);
  write ('Loop Count :');
  gotoxy (40, 4);
  write ('LPT :');
  gotoxy (35, 6);
  write ('BOX ID');
  gotoxy (7, 9);
  write ('Channel');

  adinit (addr);
  repeat
    gotoxy (23, 4);
    write (loopcount : 10);
    gotoxy (46, 4);
    write ('LPT', lpt, ' (');
    writehex (addr);
    write (')');
    for bi := 0 to boxno - 1 do
    begin
      gotoxy (20 + 6 * bi, 7);
      write ('BOX', bi+1);
      gotoxy (20 + 6 * bi, 8);
      write (box[bi]:3, '   ');
    end;
    if runstate = 1 then
    begin
      Inc(loopcount);
      for bi := 0 to boxno - 1 do
      begin
        for channel := 0 to 13 do
        begin
          gotoxy (19 + bi * 6, 10 + channel);
          write (getad(box[bi], channel):5);
        end;
      end;
    end;
    while keypressed do
    begin
      c := upcase(readkey);
      if c = 'L' then
      begin
        Inc(lpt);
        if lpt > 3 then lpt := 1;
        addr := LPTTAB[lpt];
        adinit (addr);
      end
      else if ('1' <= c) and (c <= '8') then
      begin
       i := ord(c) - ord('1');
       Inc(box[i]);
        if box[i] > 15 then
          box[i] := 0;
      end
      else if (c = chr(13)) or (c = 'G') then
        runstate := 1
      else if (c = 'S') then
        runstate := 0
      else if (c = chr(27)) then
        if runstate = 0 then
          runstate := -1
        else
          runstate := 0
      else if c = 'Q' then
        runstate := -1
      else if c = '0' then
      begin
        Inc(boxno);
        if boxno > 8 then
        begin
          boxno := 1;
          for i := 7 to 23 do
          begin
            gotoxy (19, i);
            clreol;
          end
        end
      end
    end { while }
  until runstate = -1;
  clrscr;
  cursoron;
end.
