
/* Pocket I/O Converter: Sample Program */

#include <stdio.h>
#include <dos.h>
#include <conio.h>
#include <time.h>
#include <ctype.h>

/* for test only */
#define TEST

#define LPT1 0x3BC
#define LPT2 0x378
#define LPT3 0x278

/* I/O ports for printer interface */
#define DATA(x)         (x + 0)
#define STATUS(x)       (x + 1)
#define CONTROL(x)      (x + 2)

/* definition of each data bit */
#define D7		0x80
#define D6		0x40
#define D5		0x20
#define D4		0x10
#define D3		0x08
#define D2		0x04
#define D1		0x02
#define D0		0x01

/* definition of status port */
#define BUSY	    	0x80
#define ACK         	0x40
#define PAPEROUT    	0x20
#define SELECTED    	0x10
#define ERROR       	0x08

/* definition of control port */
#define IRQENABLE	0x10
#define SELECT      	0x08
#define RESET       	0x04
#define LF          	0x02
#define STROBE      	0x01

/* pin assignments for Pocket I/O converter */
/* ADDR : box ID                            */
/* CLK  : clock for serial data in and out  */
/* DI   : data in (from box to host)        */
/* DO   : data out (from host to box)       */
/* EOC  : end of coversion                  */
#define	ADDR        	(D7 | D6 | D5 | D4)
#define LOAD		D3
#define DO		D2
#define CLK		D1
#define RW		D0
#define DI		SELECTED

static unsigned char port_value = 0;
static unsigned int port_addr = LPT1;

/* udelay : delay routine */
/* n      : loop count    */
static void
udelay (int n)
{
  int i, j;

  for (i = 0; i < n; i++)
    for (j = 0; j < 10; j++);
}

/* ioinit : initial converter           */
/* addr   : I/O address of printer port */
void
ioinit(unsigned int addr)
{
  port_addr = addr;
}

/* getdi   : get digital input value */
/* box     : box ID       	     */
int
getdi(int box)
{
  int i, r;

  port_value = (box << 4);
  outportb (DATA(port_addr), port_value);
  udelay (5);
  outportb (DATA(port_addr), port_value | LOAD);
  udelay (5);
  outportb (DATA(port_addr), port_value);
  udelay (5);
  for (r = 0, i = 0; i < 8; i++) {
    if (inportb (STATUS(port_addr)) & DI)
      r |= 0x80 >> i;
    outportb (DATA(port_addr), port_value | CLK);
    udelay (5);
    outportb (DATA(port_addr), port_value);
    udelay (5);
  }
  return r;
}

/* setdo   : set digital output value */
/* box     : box ID          	      */
/* val     : output value             */
void
setdo(int box, int val)
{
  int i;

  port_value = (box << 4) | RW;
  outportb (DATA(port_addr), port_value);
  udelay (5);
  for (i = 0; i < 8; i++) {
    if (val & (0x80 >> i))
      port_value |= DO;
    else
      port_value &= ~DO;
    outportb (DATA(port_addr), port_value);
    udelay (5);
    outportb (DATA(port_addr), port_value | CLK);
    udelay (5);
    outportb (DATA(port_addr), port_value);
    udelay (5);
  }
  outportb (DATA(port_addr), port_value | LOAD);
  udelay (5);
  outportb (DATA(port_addr), port_value);
  udelay (5);
}

#ifdef TEST

void
dumpbin(unsigned int n)
{
  int i;

  for(i = 7; i >= 0; i--) {
    cputs((n & (1 << i))? " ON  " : " OFF ");
  }
}

main ()
{
  int r, c, qflag;

  ioinit (LPT1);
  qflag = 0;
  for (;!qflag;) {
    r = getdi(0);
    printf ("\r");
    dumpbin(r);

    if (kbhit()) {
      c = getch ();
      if (c == '0')
	r = 0;
      else if (c == '9')
	r = 0xff;
      else if (c >= '1' && c <= '8')
	r =  1 << (c - '1');
      else if (c == 27) {
	r = 0;
	qflag = 1;
      }
      setdo (0, r);
      if (c >= '0' && c <= '9') {
	printf (" Output : ");
	if (c == '0')
	  printf ("  NONE ");
	else if (c == '9')
	  printf ("  ALL  ");
	else
	  printf (" CH. %d ", c - '0');
	printf (" High");
      }
    }
  }
  clrscr ();
  return 0;
}

#endif
