
{ Pocket I/O Converter: Sample Program }
uses
  Crt;

const
  LPT1 = $3BC;
  LPT2 = $378;
  LPT3 = $278;

{ I/O ports for printer interface }
  DATA    = 0;
  STATUS  = 1;
  CONTROL = 2;

{ definition of each data bit }
  D7 = $80;
  D6 = $40;
  D5 = $20;
  D4 = $10;
  D3 = $08;
  D2 = $04;
  D1 = $02;
  D0 = $01;

{ definition of status port }
  BUSY     = $80;
  ACK      = $40;
  PAPEROUT = $20;
  SELECTED = $10;
  ERROR    = $08;

{ definition of control port }
  IRQENABLE = $10;
  SELECT    = $08;
  RESET     = $04;
  LF        = $02;
  STROBE    = $01;

{ pin assignments for Pocket A/D converter     }
{ ADDR     : box ID                            }
{ CLK      : clock for serial data in and out  }
{ DATAIN   : data in (from host to box)        }
{ DATAOUTO : data out (from box to host)       }
{ EOC      : end of coversion                  }
  IDMASK  = D7 or D6 or D5 or D4;
  LOAD    = D3;
  DATAOUT = D2;
  CLK     = D1;
  RW      = D0;
  DATAIN  = SELECTED;
  LPTTAB : array[1..3] of integer = (LPT1, LPT2, LPT3);
var
  port_value : byte;
  port_addr : integer;

  lpt : integer;
  addr : integer;
  boxno, i, r : integer;
  ch : char;

{ udelay : delay routine }
{ n      : loop count    }
procedure udelay (n : integer);
var
  i,j : integer;
begin
  for i := 1 to n do
    for j := 1 to 100 do;
end;

{ ioinit : initial converter           }
{ addr   : I/O address of printer port }
procedure ioinit(addr : integer);
begin
  port_addr := addr;
  port_value := 0;
end;

{ getdi   : get digital input value }
{ box     : box ID       	    }
function getdi(box : integer) : integer;
var
  i, r : integer;
begin
  port_value := box shl 4;
  port[DATA + port_addr] :=  port_value;
  udelay(5);
  port[DATA + port_addr] :=  port_value or LOAD;
  udelay(5);
  port[DATA + port_addr] :=  port_value;
  udelay(5);
  r := 0;
  for i := 0 to 7 do
  begin
    if (port[STATUS + port_addr] and DATAIN) > 0 then
      r := r or ($80 shr i);
    port[DATA + port_addr] :=  port_value or CLK;
    udelay(5);
    port[DATA + port_addr] :=  port_value;
    udelay(5);
  end;
  getdi := r;
end;

{ setdo   : set digital output value }
{ box     : box ID          	     }
{ val     : output value             }
procedure setdo(box : integer; val : integer);
var
  i : integer;
begin
  port_value := (box shl 4) or RW;
  port[DATA + port_addr] := port_value;
  udelay(5);
  for i := 0 to 7 do
  begin
    if (val and ($80 shr i)) > 0 then
      port_value := port_value or DATAOUT
    else
      port_value := port_value and not DATAOUT;
    port[DATA + port_addr] :=  port_value;
    udelay(5);
    port[DATA + port_addr] :=  port_value or CLK;
    udelay(5);
    port[DATA + port_addr] :=  port_value;
    udelay(5);
  end;
  port[DATA + port_addr] :=  port_value or LOAD;
  udelay(5);
  port[DATA + port_addr] :=  port_value;
  udelay(5);
end;

{ dumpbin : print out ON/OFF status }
{ n       : value                   }
procedure dumpbin(n : integer);
var
  i : integer;
begin
  for i := 7 downto 0 do
    if (n and (1 shl i)) > 0 then
      write(' ON  ')
    else
      write(' OFF ');
  writeln;
end;

begin
  lpt := 1;
  addr := LPTTAB[lpt];
  boxno := 0;
  ioinit (addr);
  for i := 0 to 7 do
  begin
    setdo (boxno, 1 shl i);
    r := getdi(boxno);
    dumpbin (r);
    ch := readkey;
  end;
end.
